@@ -513,8 +513,9 @@ gnome_font_face_find_closest (const guchar *name)
 		guchar *locale, *p;
 		guchar c[128];
 		GPFontEntry *e;
-		locale = setlocale (LC_ALL, NULL);
-		if (!locale) locale = "C";
+		locale = g_strdup (setlocale (LC_ALL, NULL));
+		if (!locale)
+			locale = g_strdup ("C");
 		strncpy (c, locale, 127);
 		c[127] = '\0';
 		p = c;
@@ -530,6 +531,7 @@ gnome_font_face_find_closest (const guchar *name)
 			}
 			face = e->face;
 		}
+		g_free (locale);
 	}
 	if (!face && map->fonts) {
 		/* No face, no default, load whatever font is first */
@@ -1469,7 +1471,7 @@ gf_pso_sprintf (GFPSObject * pso, const gchar * format, ...)
 	gchar *text;
 	gint len;
 	
-	oldlocale = setlocale (LC_NUMERIC, NULL);
+	oldlocale = g_strdup (setlocale (LC_NUMERIC, NULL));
 	setlocale (LC_NUMERIC, "C");
 		
 	va_start (arguments, format);
@@ -1483,6 +1485,7 @@ gf_pso_sprintf (GFPSObject * pso, const gchar * format, ...)
 	g_free (text);
 
 	setlocale (LC_NUMERIC, oldlocale);
+	g_free (oldlocale);
 }
 
 static void
