@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+
 #ifndef __GPA_LIST_H__
 #define __GPA_LIST_H__
 
@@ -62,17 +64,14 @@ GPAList *gpa_list_construct (GPAList *list, GType childtype, gboolean has_defaul
 
 gboolean gpa_list_set_default (GPAList *list, GPANode *def);
 
+/* Debugging */
+gint     gpa_list_get_length (GPAList *list);
+
 /* Deprecated ... probably */
 GPANode *gpa_list_new (GType childtype, gboolean has_def);
 /* Deprecated ... probably */
 gboolean gpa_list_add_child (GPAList *list, GPANode *child, GPANode *ref);
 
-#if 0
-/* fixme: I am not sure about these */
-gboolean gpa_list_test_item_by_id (GPAList *list, const gchar *id);
-GPANode *gpa_list_get_item_by_id (GPAList *list, const gchar *id);
-#endif
-
 G_END_DECLS
 
 #endif
